==> ubuntu_localizations-0.2.0.tar.gz: lib/src/l10n/ubuntu_localizations_fi.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Finnish (`fi`).
class UbuntuLocalizationsFi extends UbuntuLocalizations {
  UbuntuLocalizationsFi([String locale = 'fi']) : super(locale);

  @override
  String get countryCode => 'FI';

  @override
  String get languageName => 'Suomi';

  @override
  String get backAction => 'Takaisin';

  @override
  String get continueAction => 'Jatka';

  @override
  String get strongPassword => 'Vahva salasana';

  @override
  String get fairPassword => 'Keskinkertainen salasana';

  @override
  String get goodPassword => 'Hyvä salasana';

  @override
  String get weakPassword => 'Heikko salasana';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'Tietoja';

  @override
  String get addLabel => 'Lisää';

  @override
  String get allLabel => 'Kaikki';

  @override
  String get applyLabel => 'Käytä';

  @override
  String get ascendingLabel => 'Nousevasti';

  @override
  String get backLabel => 'Takaisin';

  @override
  String get boldLabel => 'Lihavoitu';

  @override
  String get bottomLabel => 'Bottom';

  @override
  String get cancelLabel => 'Peruuta';

  @override
  String get centerLabel => 'Keskitä';

  @override
  String get clearLabel => 'Tyhjennä';

  @override
  String get closeLabel => 'Sulje';

  @override
  String get colorLabel => 'Väri';

  @override
  String get connectLabel => 'Yhdistä';

  @override
  String get continueLabel => 'Jatka';

  @override
  String get copyLabel => 'Kopioi';

  @override
  String get createLabel => 'Luo';

  @override
  String get cutLabel => 'Leikkaa';

  @override
  String get decreaseLabel => 'Vähennä';

  @override
  String get deleteLabel => 'Poista';

  @override
  String get descendingLabel => 'Laskevasti';

  @override
  String get discardLabel => 'Hylkää';

  @override
  String get disconnectLabel => 'Katkaise yhteys';

  @override
  String get doneLabel => 'Valmis';

  @override
  String get downloadLabel => 'Lataa';

  @override
  String get editLabel => 'Muokkaa';

  @override
  String get enterLabel => 'Enter';

  @override
  String get errorLabel => 'Virhe';

  @override
  String get executeLabel => 'Suorita';

  @override
  String get exitLabel => 'Poistu';

  @override
  String get fileLabel => 'Tiedosto';

  @override
  String get fillLabel => 'Täytä';

  @override
  String get findLabel => 'Etsi';

  @override
  String get firstLabel => 'Ensimmäinen';

  @override
  String get fontLabel => 'Fontti';

  @override
  String get forwardLabel => 'Forward';

  @override
  String get fullscreenLabel => 'Koko näyttö';

  @override
  String get goBackLabel => 'Takaisin';

  @override
  String get helpLabel => 'Ohje';

  @override
  String get homeLabel => 'Koti';

  @override
  String get importLabel => 'Tuo';

  @override
  String get increaseLabel => 'Lisää';

  @override
  String get indexLabel => 'Index';

  @override
  String get informationLabel => 'Tiedot';

  @override
  String get insertLabel => 'Lisää';

  @override
  String get italicLabel => 'Kursivoitu';

  @override
  String get landscapeLabel => 'Vaakasuunta';

  @override
  String get lastLabel => 'Viimeinen';

  @override
  String get leaveLabel => 'Poistu';

  @override
  String get leftLabel => 'Vasen';

  @override
  String get mediaLabel => 'Media';

  @override
  String get networkLabel => 'Verkko';

  @override
  String get newLabel => 'Uusi';

  @override
  String get nextLabel => 'Seuraava';

  @override
  String get noLabel => 'Ei';

  @override
  String get noneLabel => 'Ei mitään';

  @override
  String get normalLabel => 'Normaali';

  @override
  String get okLabel => 'OK';

  @override
  String get openLabel => 'Avaa';

  @override
  String get pasteLabel => 'Liitä';

  @override
  String get pauseLabel => 'Keskeytä';

  @override
  String get playLabel => 'Toista';

  @override
  String get portraitLabel => 'Pystysuunta';

  @override
  String get preferencesLabel => 'Asetukset';

  @override
  String get previousLabel => 'Edellinen';

  @override
  String get printLabel => 'Tulosta';

  @override
  String get printPreviewLabel => 'Tulostuksen esikatselu';

  @override
  String get propertiesLabel => 'Ominaisuudet';

  @override
  String get questionLabel => 'Kysymys';

  @override
  String get quitLabel => 'Lopeta';

  @override
  String get recordLabel => 'Nauhoita';

  @override
  String get redoLabel => 'Tee uudelleen';

  @override
  String get refreshLabel => 'Päivitä';

  @override
  String get removeLabel => 'Poista';

  @override
  String get renameLabel => 'Nimeä uudelleen';

  @override
  String get resetLabel => 'Palauta';

  @override
  String get restoreLabel => 'Palauta';

  @override
  String get retryLabel => 'Yritä uudelleen';

  @override
  String get revertLabel => 'Kumoa';

  @override
  String get rewindLabel => 'Rewind';

  @override
  String get rightLabel => 'Oikea';

  @override
  String get saveAsLabel => 'Tallenna nimellä';

  @override
  String get saveLabel => 'Tallenna';

  @override
  String get searchLabel => 'Hae';

  @override
  String get selectAllLabel => 'Valitse kaikki';

  @override
  String get selectLabel => 'Valitse';

  @override
  String get sendLabel => 'Lähetä';

  @override
  String get skipLabel => 'Ohita';

  @override
  String get sortLabel => 'Järjestä';

  @override
  String get stopLabel => 'Pysäytä';

  @override
  String get strikeThroughLabel => 'Yliviivattu';

  @override
  String get submitLabel => 'Lähetä';

  @override
  String get topLabel => 'Top';

  @override
  String get undoLabel => 'Kumoa';

  @override
  String get updateLabel => 'Päivitä';

  @override
  String get upLabel => 'Ylös';

  @override
  String get viewLabel => 'Näytä';

  @override
  String get warningLabel => 'Varoitus';

  @override
  String get windowLabel => 'Ikkuna';

  @override
  String get yesLabel => 'Kyllä';

  @override
  String get zoomInLabel => 'Lähennä';

  @override
  String get zoomOutLabel => 'Loitonna';
}

==> ubuntu_localizations-0.2.1.tar.gz: lib/src/l10n/ubuntu_localizations_fi.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Finnish (`fi`).
class UbuntuLocalizationsFi extends UbuntuLocalizations {
  UbuntuLocalizationsFi([String locale = 'fi']) : super(locale);

  @override
  String get countryCode => 'FI';

  @override
  String get languageName => 'Suomi';

  @override
  String get backAction => 'Takaisin';

  @override
  String get continueAction => 'Jatka';

  @override
  String get strongPassword => 'Vahva salasana';

  @override
  String get fairPassword => 'Keskinkertainen salasana';

  @override
  String get goodPassword => 'Hyvä salasana';

  @override
  String get weakPassword => 'Heikko salasana';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'Tietoja';

  @override
  String get addLabel => 'Lisää';

  @override
  String get allLabel => 'Kaikki';

  @override
  String get applyLabel => 'Käytä';

  @override
  String get ascendingLabel => 'Nousevasti';

  @override
  String get backLabel => 'Takaisin';

  @override
  String get boldLabel => 'Lihavoitu';

  @override
  String get bottomLabel => 'Bottom';

  @override
  String get cancelLabel => 'Peru';

  @override
  String get centerLabel => 'Keskitä';

  @override
  String get clearLabel => 'Tyhjennä';

  @override
  String get closeLabel => 'Sulje';

  @override
  String get colorLabel => 'Väri';

  @override
  String get connectLabel => 'Yhdistä';

  @override
  String get continueLabel => 'Jatka';

  @override
  String get copyLabel => 'Kopioi';

  @override
  String get createLabel => 'Luo';

  @override
  String get cutLabel => 'Leikkaa';

  @override
  String get decreaseLabel => 'Vähennä';

  @override
  String get deleteLabel => 'Poista';

  @override
  String get descendingLabel => 'Laskevasti';

  @override
  String get discardLabel => 'Hylkää';

  @override
  String get disconnectLabel => 'Katkaise yhteys';

  @override
  String get doneLabel => 'Valmis';

  @override
  String get downloadLabel => 'Lataa';

  @override
  String get editLabel => 'Muokkaa';

  @override
  String get enterLabel => 'Enter';

  @override
  String get errorLabel => 'Virhe';

  @override
  String get executeLabel => 'Suorita';

  @override
  String get exitLabel => 'Poistu';

  @override
  String get fileLabel => 'Tiedosto';

  @override
  String get fillLabel => 'Täytä';

  @override
  String get findLabel => 'Etsi';

  @override
  String get firstLabel => 'Ensimmäinen';

  @override
  String get fontLabel => 'Fontti';

  @override
  String get forwardLabel => 'Forward';

  @override
  String get fullscreenLabel => 'Koko näyttö';

  @override
  String get goBackLabel => 'Takaisin';

  @override
  String get helpLabel => 'Ohje';

  @override
  String get homeLabel => 'Koti';

  @override
  String get importLabel => 'Tuo';

  @override
  String get increaseLabel => 'Lisää';

  @override
  String get indexLabel => 'Index';

  @override
  String get informationLabel => 'Tiedot';

  @override
  String get insertLabel => 'Lisää';

  @override
  String get italicLabel => 'Kursivoitu';

  @override
  String get landscapeLabel => 'Vaakasuunta';

  @override
  String get lastLabel => 'Viimeinen';

  @override
  String get leaveLabel => 'Poistu';

  @override
  String get leftLabel => 'Vasen';

  @override
  String get mediaLabel => 'Media';

  @override
  String get networkLabel => 'Verkko';

  @override
  String get newLabel => 'Uusi';

  @override
  String get nextLabel => 'Seuraava';

  @override
  String get noLabel => 'Ei';

  @override
  String get noneLabel => 'Ei mitään';

  @override
  String get normalLabel => 'Normaali';

  @override
  String get okLabel => 'OK';

  @override
  String get openLabel => 'Avaa';

  @override
  String get pasteLabel => 'Liitä';

  @override
  String get pauseLabel => 'Keskeytä';

  @override
  String get playLabel => 'Toista';

  @override
  String get portraitLabel => 'Pystysuunta';

  @override
  String get preferencesLabel => 'Asetukset';

  @override
  String get previousLabel => 'Edellinen';

  @override
  String get printLabel => 'Tulosta';

  @override
  String get printPreviewLabel => 'Tulostuksen esikatselu';

  @override
  String get propertiesLabel => 'Ominaisuudet';

  @override
  String get questionLabel => 'Kysymys';

  @override
  String get quitLabel => 'Lopeta';

  @override
  String get recordLabel => 'Nauhoita';

  @override
  String get redoLabel => 'Tee uudelleen';

  @override
  String get refreshLabel => 'Päivitä';

  @override
  String get removeLabel => 'Poista';

  @override
  String get renameLabel => 'Nimeä uudelleen';

  @override
  String get resetLabel => 'Palauta';

  @override
  String get restoreLabel => 'Palauta';

  @override
  String get retryLabel => 'Yritä uudelleen';

  @override
  String get revertLabel => 'Kumoa';

  @override
  String get rewindLabel => 'Rewind';

  @override
  String get rightLabel => 'Oikea';

  @override
  String get saveAsLabel => 'Tallenna nimellä';

  @override
  String get saveLabel => 'Tallenna';

  @override
  String get searchLabel => 'Hae';

  @override
  String get selectAllLabel => 'Valitse kaikki';

  @override
  String get selectLabel => 'Valitse';

  @override
  String get sendLabel => 'Lähetä';

  @override
  String get skipLabel => 'Ohita';

  @override
  String get sortLabel => 'Järjestä';

  @override
  String get stopLabel => 'Pysäytä';

  @override
  String get strikeThroughLabel => 'Yliviivattu';

  @override
  String get submitLabel => 'Lähetä';

  @override
  String get topLabel => 'Top';

  @override
  String get undoLabel => 'Kumoa';

  @override
  String get updateLabel => 'Päivitä';

  @override
  String get upLabel => 'Ylös';

  @override
  String get viewLabel => 'Näytä';

  @override
  String get warningLabel => 'Varoitus';

  @override
  String get windowLabel => 'Ikkuna';

  @override
  String get yesLabel => 'Kyllä';

  @override
  String get zoomInLabel => 'Lähennä';

  @override
  String get zoomOutLabel => 'Loitonna';
}
